==> guikachu-1.2.3.tar.gz: guikachu-1.2.3/src/form-editor/text-field.h <==
//$Id: text-field.h,v 1.9 2002/02/10 00:01:19 cactus Exp $ -*- c++ -*-

/* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2
 * as published by the Free Software Foundation.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#ifndef GUIKACHU_FORM_EDITOR_TEXT_FIELD_H
#define GUIKACHU_FORM_EDITOR_TEXT_FIELD_H

namespace Guikachu
{
    namespace Widgets
    {
	class TextField;
    }
}

#include "widget.h"
#include "auto-resizeable.h"

#include "text-field-prop.h"

namespace Guikachu
{
    namespace Widgets
    {
	class TextField: public Widget,
			 public AutoHeight
	{
	    GUI::FormEditor::TextFieldProperties *editor;
	    
	public:
	    TextField (Resources::Form   *owner,
		       const std::string &id);
	    virtual ~TextField ();
	    
	    virtual Type get_type () const { return WIDGET_TEXT_FIELD; };
	    
	    virtual Gtk::Widget                       *create_editor ();
	    virtual GUI::FormEditor::WidgetCanvasItem *create_canvas_item (Gnome::CanvasGroup *parent_group);

	    Property<bool> usable;

	    Property<int>  font;
	    Property<bool> editable;
	    Property<bool> multi_line;
	    Property<bool> auto_shift;
	    Property<int>  max_length;
	    Property<bool> numeric;
	    
	    Property<bool> underline;
	    Property<bool> dynamic_size;
	    Property<bool> justify_right;
	    Property<bool> has_scrollbar;

	protected:
	    int get_auto_height () const;

	public:
	    int get_display_height () const;
	    
	private:
	    // Persistance
	    bool load (StorageNode &node);
	    void save (StorageNode &node) const;
	    void save_rcp (std::ostream &ostr) const;
	};
    }
}

#endif /* !GUIKACHU_FORM_EDITOR_TEXT_FIELD_H */

==> guikachu-1.3.0.tar.gz: guikachu-1.3.0/src/form-editor/text-field.h <==
//$Id: text-field.h,v 1.13 2002/06/19 21:57:39 cactus Exp $ -*- c++ -*-

/* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2
 * as published by the Free Software Foundation.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#ifndef GUIKACHU_FORM_EDITOR_TEXT_FIELD_H
#define GUIKACHU_FORM_EDITOR_TEXT_FIELD_H

namespace Guikachu
{
    namespace Widgets
    {
	class TextField;
    }
}

#include "widget.h"
#include "auto-resizeable.h"

#include "text-field-prop.h"

namespace Guikachu
{
    namespace Widgets
    {
	class TextField: public Widget,
			 public AutoHeight
	{
	    GUI::FormEditor::TextFieldProperties *editor;
	    
	public:
	    TextField (Resources::Form   *owner,
		       const std::string &id);
	    virtual ~TextField ();
	    
	    virtual Type get_type () const { return WIDGET_TEXT_FIELD; };
	    
	    virtual Gtk::Widget                       *create_editor ();
	    virtual GUI::FormEditor::WidgetCanvasItem *create_canvas_item (Gnome::CanvasGroup *parent_group);

	    Property<bool> usable;

	    Property<int>  font;
	    Property<bool> editable;
	    Property<bool> multi_line;
	    Property<bool> auto_shift;
	    Property<int>  max_length;
	    Property<bool> numeric;
	    
	    Property<bool> underline;
	    Property<bool> dynamic_size;
	    Property<bool> justify_right;
	    Property<bool> has_scrollbar;

	protected:
	    int get_auto_height () const;

	public:
	    int get_height () const;
	};
    }
}

#endif /* !GUIKACHU_FORM_EDITOR_TEXT_FIELD_H */
